@echo off
rem -------------------------------------------------------------------------------
rem Licensed Materials - Property of IBM and/or HCL
rem (c) Copyright IBM Corporation 2001, 2016. All Rights Reserved.
rem (c) Copyright HCL Technologies 2018. All Rights Reserved.
rem 
rem Note to U.S. Government Users Restricted Rights:  
rem Use, duplication or disclosure restricted by GSA ADP Schedule 
rem Contract with IBM Corp. 
rem -------------------------------------------------------------------------------
rem Configure WebSphere MQ authorizations Script
rem
rem Arguments: -g queueManagerName ITEntity puttingApplicationEntity stubbedQueueName responseQueueName
rem
rem -g
rem          Group mode. Set authorizations for groups instead of users. 
rem          Defaults to setting authorizations for users. (Optional)
rem queueManagerName
rem          The name of the local queue manager to configure authorizations for.
rem ITEntity
rem          The user ID configured in the physical resources in Integration
rem          Tester or, the name of a group that the user belongs to
rem puttingApplicationEntity
rem          The user ID used by the existing application putting messages onto MQ queues or,
rem          the name of a group that the user belongs to.
rem stubbedQueueName
rem          The name of the queue that the Stub will be reading messages from.
rem responseQueueName
rem          The name of the queue that stubbed messages should be placed onto. (Optional)
rem -------------------------------------------------------------------------------

setlocal

rem ---- Check to see whether we should apply authorizations for users or groups
rem      Defaults to users ----
SET entityType=-p

if "%1"=="-g" (
    SET entityType=-g
    SHIFT
)

rem ---- Check to see if a response queue has been set ----
if "x%5x" NEQ "xx" (
	SET responseQueue=%5
	SHIFT /5
)

if "x%4x" == "xx" goto PrintUsage
if "x%5x" NEQ "xx" goto PrintUsage

rem Dump all existing queue manager authorities to file prior to running the setmqaut commands
dmpmqaut -m %1 > preSiftAndPassThroughAuthorityBackup.aut 2>&1

rem ---- Set authorizations to enable access for the MQ user configured in RIT ----
setmqaut -m %1 -t qmgr %entityType% "%2" +connect +inq +dsp +setall
setmqaut -m %1 -n "rit.divert.rules*" -t namelist %entityType% "%2" +chg +inq +dsp
setmqaut -m %1 -n %4 -t q %entityType% "%2" +put +setall
setmqaut -m %1 -n SYSTEM.DURABLE.MODEL.QUEUE -t q %entityType% "%2" +get +dsp
setmqaut -m %1 -n SYSTEM.ADMIN.COMMAND.QUEUE -t q %entityType% "%2" +put +inq
setmqaut -m %1 -n SYSTEM.DEFAULT.MODEL.QUEUE -t q %entityType% "%2" +get +dsp
setmqaut -m %1 -n SYSTEM.DEFAULT.NAMELIST -t namelist %entityType% "%2" +dsp
setmqaut -m %1 -n "**" -t namelist %entityType% "%2" +crt
setmqaut -m %1 -n "SYSTEM.DEFAULT.LOCAL.QUEUE" -t q %entityType% "%2" +dsp
setmqaut -m %1 -n "**" -t q %entityType% "%2" +crt
IF DEFINED responseQueue (
    setmqaut -m %1 -n "%responseQueue%" -t q %entityType% "%2" +put
)

rem ---- Set authorizations to enable access for the MQ user used by the existing application ----
setmqaut -m %1 -t qmgr %entityType% "%3" +connect +inq
setmqaut -m %1 -n "rit.divert.rules*" -t namelist %entityType% "%3" +inq
setmqaut -m %1 -n "SYSTEM.DURABLE.MODEL.QUEUE" -t q %entityType% "%3" +get +put
setmqaut -m %1 -n "SYSTEM.DEFAULT.MODEL.QUEUE" -t q %entityType% "%3" +put +setall

goto End

:PrintUsage
echo arguments: [-g] queueManagerName ITEntity puttingApplicationEntity stubbedQueueName [responseQueueName]
echo -g
echo    Group mode. Set authorizations for groups instead of users. 
echo    Defaults to setting authorizations for users. (Optional)
echo.
echo queueManagerName
echo    The name of the local queue manager to configure authorizations for.
echo.
echo ITEntity
echo    The user ID configured in the physical resource in Integration Tester or, the name of a group that the user belongs to.
echo.
echo puttingApplicationEntity
echo    The user ID used by the existing application putting messages onto MQ queues or, the name of a group that the user belongs to.
echo.
echo stubbedQueueName
echo    The name of the queue that the Stub will be reading messages from
echo.
echo responseQueueName
echo    The name of the queue that stubbed messages should be placed onto. (Optional)

:End

endlocal
